Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 1860)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 1861)
@@ -1,3 +1,9 @@
                                                  -*-*- END OF LINE -*-*-
+ 2003/03/24: Abelardo Moralejo
+
+    * manalysis/MEnergyEstParam.cc
+      - now energy estimation (for CT1) is done using the same model 
+	as in D.Krannich's thesis.
+
  2003/03/21: Thomas Hengstebeck
  
Index: /trunk/MagicSoft/Mars/manalysis/MEnergyEstParam.cc
===================================================================
--- /trunk/MagicSoft/Mars/manalysis/MEnergyEstParam.cc	(revision 1860)
+++ /trunk/MagicSoft/Mars/manalysis/MEnergyEstParam.cc	(revision 1861)
@@ -88,5 +88,5 @@
 //
 // Default constructor. Give the name of the parameter container (MHillas)
 // storing wisth, length and size (Default="MHillas").
 // For the Zenith Angle MMcEvt.fTheta is used.
 //
@@ -273,5 +273,5 @@
 // Add a pair of input/output containers.
 //   eg. Add("MHillasSrc", "MEnergyEst");
-// Usefull if you want to estimate the stuff for the source and antisource
+// Useful if you want to estimate the stuff for the source and antisource
 //
 void MEnergyEstParam::Add(const TString hillas, const TString energy)
@@ -308,4 +308,5 @@
     const Double_t i1 = fA[0] + fA[2]*width;
 
+
     const Double_t e0 = k2 * (fB[6]*k2+1)/(fB[6]+1);
 
@@ -315,5 +316,13 @@
 
     /* MARCOS */
+    /*
     const Double_t e1 = fB[0] + fB[1]*size + fB[3]*length + fB[4]*size*length;
+    const Double_t e2 = fB[2] + fB[5]*length;
+    */
+
+    /* DANIEL */
+    const Double_t e1 = fB[0] + fB[1]*size/(length*width) + 
+      fB[3]*length + fB[4]*size/width;
+
     const Double_t e2 = fB[2] + fB[5]*length;
 
@@ -332,11 +341,12 @@
 
 
-        /* MARCOS */
+        /* DANIEL - MARCOS */
         const Double_t ir = i0 * (i1 + fA[1]*dist); // [cm]
-        /*const*/ Double_t er = e0 * (e1 + e2*0/*ir*/);      // [GeV]
+        Double_t er = e0 * (e1 + e2*ir);       // [GeV]
+
 
         /* MY PARAM */
         // if (width==0) return kCONTINUE;
-        //const Double_t ir = i0 * (i1 + dist*(fA[1]/width + fA[4]/log10(size))); // [cm]
+        // const Double_t ir = i0 * (i1 + dist*(fA[1]/width + fA[4]/log10(size))); // [cm]
         //Double_t er = e0 * (e1 + e2*ir);      // [GeV]
 
@@ -88,5 +88,5 @@
 //
 // Default constructor. Give the name of the parameter container (MHillas)
-// storing wisth, length and size (Default="MHillas").
+// storing width, length and size (Default="MHillas").
 // For the Zenith Angle MMcEvt.fTheta is used.
 //
